@@ -1,5 +1,7 @@
 """Django ORM models for Social Auth"""
 
+from typing import Union
+
 from django.conf import settings
 from django.db import models
 from django.db.utils import IntegrityError
@@ -41,7 +43,7 @@ class AbstractUserSocialAuth(models.Model, DjangoUserMixin):
     )
     provider = models.CharField(max_length=32)
     uid = models.CharField(max_length=UID_LENGTH, db_index=True)
-    extra_data = models.JSONField(default=dict)
+    extra_data = models.JSONField(default=dict, blank=True)
     created = models.DateTimeField(auto_now_add=True)
     modified = models.DateTimeField(auto_now=True)
     objects = UserSocialAuthManager()
@@ -54,7 +56,9 @@ class AbstractUserSocialAuth(models.Model, DjangoUserMixin):
         abstract = True
 
     @classmethod
-    def get_social_auth(cls, provider: str, uid: str):
+    def get_social_auth(cls, provider: str, uid: Union[str, int]):
+        if not isinstance(uid, str):
+            uid = str(uid)
         for social in cls.objects.select_related("user").filter(
             provider=provider, uid=uid
         ):
